/*

Replication do-file for:
Hultman, Lisa, Jacob Kathman, and Megan Shannon. 2014. "Beyond Keeping Peace: United Nations Effectiveness in the Midst of Fighting." 
American Political Science Review 108(4): 737-753.

Use together with the following replication datasets: 
"HKS APSR 108(4) main dataset.dta"
"HKS APSR 108(4) matched.dta"

*/


***************************************
*	MODELS REPORTED IN THE ARTICLE
***************************************

Use ".../HKS APSR 108(4) main dataset.dta"
sort dyad_id yearmon

**** TABLE 1 ****

*	Model 1
nbreg brv_All troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention brv_AllLag if active_year==1 | peacedurplus24!=., cl(dyad_id)

*	Model 2
clear
Use ".../HKS APSR 108(4) matched.dta"
nbreg brv_All troopLag1000 policeLag1000 milobsLag1000 if _weight==1

*	Model 3
clear
Use ".../HKS APSR 108(4) main dataset.dta"
sort dyad_id yearmon
xtnbreg brv_All troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention brv_AllLag if active_year==1 | peacedurplus24!=., fe i(ConflictID)

*	Model 4
drop if active_year ~= 1 & peacedurplus24 == .
by dyad_id: gen count = _n if dyad_id == dyad_id & active_year == 1 | peacedurplus24 ~= .
gen cubictime = count*count*count
xtnbreg brv_All troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention cubictime brv_AllLag if active_year==1 | peacedurplus24!=., fe i(ConflictID)


**** TABLE 2 ****
clear
Use ".../HKS APSR 108(4) main dataset.dta"
sort dyad_id yearmon

*	Model 5
nbreg brv_All troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention battlechange brv_AllLag if active_year==1 | peacedurplus24!=., cl(dyad_id)

*	Model 6
nbreg brv_All troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention brv_AllLag if (active_year==1 | peacedurplus24!=.) & PKOdumLag == 1, cl(dyad_id)

*	Model 7
nbreg brv_All troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention MullenregionaligopkLag brv_AllLag if active_year==1 | peacedurplus24!=., cl(dyad_id)

*	Model 8
nbreg brv_All troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention unscres_prearrivalLag brv_AllLag if active_year==1 | peacedurplus24!=., cl(dyad_id)



****************************************************
*	MODELS REPORTED IN SUPPLEMENTARY INFORMATION
****************************************************
Use ".../HKS APSR 108(4) main dataset.dta"
sort dyad_id yearmon

**** TABLE S2 ****

*	48 months
nbreg brv_All troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention brv_AllLag if active_year==1 | peacedurplus48!=., cl(dyad_id)
*	36 months
nbreg brv_All troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention brv_AllLag if active_year==1 | peacedurplus36!=., cl(dyad_id)
*	12 months
nbreg brv_All troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention brv_AllLag if active_year==1 | peacedurplus24<=12, cl(dyad_id)
*	0 months
nbreg brv_All troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention brv_AllLag if active_year==1, cl(dyad_id)


**** TABLE S3 ****

*	All covariates
nbreg brv_All troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention brv_AllLag battlechange MullenregionaligopkLag unscres_prearrivalLag if active_year==1 | peacedurplus24!=., cl(dyad_id)


**** TABLE S4 ****

*	Model 1
nbreg brv_rebgov troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention brv_rebgovLag if active_year==1 | peacedurplus24!=., cl(dyad_id)
*	Model 5
nbreg brv_rebgov troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention battlechange brv_rebgovLag if active_year==1 | peacedurplus24!=., cl(dyad_id)
*	Model 6
nbreg brv_rebgov troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention brv_rebgovLag if (active_year==1 | peacedurplus24!=.) & PKOdumLag == 1, cl(dyad_id)
*	Model 7
nbreg brv_rebgov troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention MullenregionaligopkLag brv_rebgovLag if active_year==1 | peacedurplus24!=., cl(dyad_id)
*	Model 8
nbreg brv_rebgov troopLag1000 policeLag1000 milobsLag1000 ceasefire rebstrength numofrebgroups lntpop biased_intervention unscres_prearrivalLag brv_rebgovLag if active_year==1 | peacedurplus24!=., cl(dyad_id)


**** TABLE S5 ****

*	Model 1
nbreg brv_All PKOdumLag ceasefire rebstrength numofrebgroups lntpop biased_intervention brv_AllLag if active_year==1 | peacedurplus24!=., cl(dyad_id)
*	Model 5
nbreg brv_All PKOdumLag ceasefire rebstrength numofrebgroups lntpop biased_intervention battlechange brv_AllLag if active_year==1 | peacedurplus24!=., cl(dyad_id)
*	Model 7
nbreg brv_All PKOdumLag ceasefire rebstrength numofrebgroups lntpop biased_intervention MullenregionaligopkLag brv_AllLag if active_year==1 | peacedurplus24!=., cl(dyad_id)
*	Model 8
nbreg brv_All PKOdumLag ceasefire rebstrength numofrebgroups lntpop biased_intervention unscres_prearrivalLag brv_AllLag if active_year==1 | peacedurplus24!=., cl(dyad_id)


